@@ -3,7 +3,7 @@ import requests
 from .load_setting import load_setting
 
 
-def get_url_with_id(url_param):
+def get_id_with_url(url_param):
     """
     通过url获取id,使用华为云服务器，POST请求
     :param url_param:文档下载连接
@@ -13,7 +13,7 @@ def get_url_with_id(url_param):
 
     SETTING = load_setting()
     url = SETTING['url']['HuaweiCould Interface'] + 'url_to_id/'  # 线上运行url
-
+    print(url)
     body = {"url": url_param}
     response = requests.post(url, json=body)
     data = response.json()
@@ -23,7 +23,7 @@ def get_url_with_id(url_param):
         return "函数get_url_with_id出现错误，请检查输入的url_param是否正确"
 
 
-def get_id_with_url(id):
+def get_url_with_id(id):
     """
     通过id获取url,使用华为云服务器， GET请求
     :param id: 数据id
